Module session

Module session 

Session types and management for thulp.

This module provides session tracking for conversation history, evaluation runs, and skill execution sessions.

Structs

Session
Complete session data.
SessionConfig
Configuration for session limits.
SessionEntry
A single entry in a session.
SessionId
Unique session identifier.
SessionMetadata
Session metadata.
Timestamp
Timestamp in milliseconds since Unix epoch.

Enums

EntryType
Type of entry in a session.
LimitAction
Action to take when a session limit is reached.
LimitCheck
Check result for session limits.
LimitExceeded
Which limit was exceeded.
SessionStatus
Status of a session.
SessionType
Type of session.