Session

Struct Session 

pub struct Session {
    pub metadata: SessionMetadata,
    pub entries: Vec<SessionEntry>,
    pub context: HashMap<String, Value>,
}
Complete session data.

Fields

metadata: SessionMetadata

Session metadata.

entries: Vec<SessionEntry>

Session entries (conversation history, tool calls, etc.).

context: HashMap<String, Value>

Session context data (key-value store).

Implementations

Source

impl Session

pub fn new(name: impl Into<String>, session_type: SessionType) -> Self

Create a new session.

pub fn id(&self) -> &SessionId

Get the session ID.

pub fn name(&self) -> &str

Get the session name.

pub fn status(&self) -> SessionStatus

Get the session status.

pub fn add_entry(&mut self, entry: SessionEntry)

Add an entry to the session.

pub fn add_user_message(&mut self, content: impl Into<String>)

Add a user message.

pub fn add_assistant_message(&mut self, content: impl Into<String>)

Add an assistant message.

pub fn set_context(&mut self, key: impl Into<String>, value: Value)

Set context value.

pub fn get_context(&self, key: &str) -> Option<&Value>

Get context value.

pub fn set_status(&mut self, status: SessionStatus)

Update session status.

pub fn complete(&mut self)

Mark session as completed.

pub fn fail(&mut self)

Mark session as failed.

pub fn turn_count(&self) -> u32

Count the number of turns in the session.

A turn is defined as a user message followed by an assistant message. This counts the number of complete turns.

pub fn user_message_count(&self) -> usize

Count user messages in the session.

pub fn assistant_message_count(&self) -> usize

Count assistant messages in the session.

pub fn duration(&self) -> Duration

Get the duration of the session.

Source

impl Session

pub fn check_limits(&self, config: &SessionConfig) -> LimitCheck

Check if the session is within limits.

pub fn is_at_turn_limit(&self, config: &SessionConfig) -> bool

Check if the session is at its turn limit.

pub fn remaining_turns(&self, config: &SessionConfig) -> Option<u32>

Get remaining turns before limit.